/*
	* Copyright (c) 2021-11 by ELECTRONIC ASSEMBLY <technik@lcd-module.de>
	*
	* Bluetooth serial access to ESP32. Wrapper for BluetoothSerial.h
	*
	* This file is free software; you can redistribute it and/or modify
	* it under the terms of either the GNU General Public License version 2
	* or the GNU Lesser General Public License version 2.1, both as
	* published by the Free Software Foundation.
*/
#include "../../debug.h"
#include "bluetooth.h"
#include "../SmallProtocol/uniTFT.h"
#include "../Wifi/wifi_ea.h"
#include <BluetoothSerial.h>


Bluetooth BT_serial;
/**
	ATTENTION:
	change BT rx and tx buffer in BluetoothSerial.h to 2048 Bytes!!!!
	Largest packet sizes are 2048 byte comming from uniTFT ShortProtocol
**/

BluetoothSerial SerialBT; //global Serial bluetooth object. Only use in this class.

/*----------------------------
	Func: setup
	Desc: Connects to bluetooth
	Vars: name
	Ret : ---
------------------------------*/
void Bluetooth::setup(char *name) 
{
	pinMode(BT_RESETPIN, INPUT_PULLUP); //hardware setup. Only activate bluetooth direct if this pin is low
	if(name) //only activate bluetooth if name pointer is not NULL
	{
		WiFi_EA.disconnect(); //wifi off
		uniTFT.initialize_rs232_newBaud(BAUDUNITFT_DIRECT); //set connection to uniTFT to new faster baudrate
		SerialBT.begin(name); //turn on bluetooth serial
		#if (DBG_ON && DBG_BLUETOOTH)
			Serial.printf("Start BT virtual COM %s. Reset Baudrate uniTFT to %d\r\n", name, BAUDUNITFT_DIRECT);
		#endif
	}
}

/*----------------------------
	Func: serial
	Desc: Checks if data is available and send to other side
	Vars: ---
	Ret : ---
------------------------------*/
void Bluetooth::serial()
{
	while(uniTFT.rs232_direct_available()) //uniTFT has data, send to bluetooth serial port
		SerialBT.write(uniTFT.rs232_direct_read());
	
	while(SerialBT.available()) //bluetooth serial port has data, send to uniTFT
		uniTFT.rs232_direct_write(SerialBT.read());
	
}

/*----------------------------
	Func: end
	Desc: Turn off bluetooth
	Vars: ---
	Ret : ---
------------------------------*/
void Bluetooth::end()
{
	SerialBT.end(); //Bluetooth off
	uniTFT.initialize_rs232_newBaud(BAUDUNITFT); //Baudrate to uniTFT back to default
	#if (DBG_ON && DBG_BLUETOOTH)
		Serial.printf("Stop BT virtual COM. Reset Baudrate uniTFT to %d\r\n", BAUDUNITFT);
	#endif
	WiFi_EA.reconnect(); //WiFi reconnect
}